"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable no-console */
/* eslint-disable import/prefer-default-export */
const fs_extra_1 = require("fs-extra");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const path_1 = require("path");
const ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
const paths_1 = require("../config/paths");
const genDoczFiles_1 = tslib_1.__importDefault(require("./genDoczFiles"));
const updateREADMEFile_1 = tslib_1.__importDefault(require("./fns/updateREADMEFile"));
const updateLicense_1 = tslib_1.__importDefault(require("./fns/updateLicense"));
/**
 * 生成package.json文件
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
async function genPackageFile(projectPath, options) {
    const packagePath = path_1.resolve(projectPath, 'package.json');
    const packageInfo = await fs_extra_1.readJSON(packagePath);
    packageInfo.version = options.packageVersion;
    packageInfo.name = options.packageName;
    packageInfo.description = options.packageDescription;
    packageInfo.files = ['dist', 'assets'];
    packageInfo['umd:main'] = `dist/${ts_lib_scripts_utils_1.safePackageName(options.packageName)}.umd.production.js`;
    packageInfo.module = `dist/${ts_lib_scripts_utils_1.safePackageName(options.packageName)}.esm.js`;
    await fs_extra_1.outputJSON(packagePath, packageInfo, {
        spaces: 2,
    });
}
exports.genPackageFile = genPackageFile;
/**
 * 生成项目
 *
 * @param options 配置
 */
async function genProject(options) {
    const projectPath = paths_1.resolveRoot(options.projectName);
    const exists = await fs_extra_1.pathExists(projectPath);
    if (exists) {
        console.error(chalk_1.default.red(`已经存在${options.projectName}文件夹，请选择一个新的项目名称。`));
        process.exit(1);
    }
    await fs_extra_1.copy(paths_1.COMMON_TEMPLATE_PATH, projectPath);
    await fs_extra_1.copy(options.react ? paths_1.REACT_TEMPLATE_PATH : paths_1.TEMPLATE_PATH, projectPath);
    await fs_extra_1.copy(paths_1.GIT_IGNORE_FILE_PATH, path_1.resolve(projectPath, '.gitignore'));
    await fs_extra_1.copy(paths_1.NPM_IGNORE_FILE_PATH, path_1.resolve(projectPath, '.npmignore'));
    await genPackageFile(projectPath, options);
    await updateREADMEFile_1.default(projectPath, options);
    await updateLicense_1.default(projectPath, options);
    if (options.docz) {
        await genDoczFiles_1.default(projectPath, options);
    }
}
exports.genProject = genProject;
//# sourceMappingURL=genProject.js.map