"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
const messages_1 = require("./messages");
const constants_1 = require("./constants");
const paths_1 = require("../config/paths");
const execa = require("execa");
function getDevPendencies(options) {
    return [
        ...constants_1.devDependencies,
        ...(options.react ? constants_1.devDependenciesForReact : []),
        ...(options.docz ? constants_1.devDependenciesForDocz : []),
        ...(options.doczGithubPages ? constants_1.devDependenciesForGhpages : []),
        ...(options.monorepo ? constants_1.monorepoDevDependencies : []),
    ];
}
/**
 * 执行安装依赖的命令
 *
 * @param projectName 项目名称
 * @param deps 依赖
 * @param isDev 是否是开发依赖
 */
async function execInstallDeps(projectName, deps, isDev = false, monorepo = false) {
    const cmd = ts_lib_scripts_utils_1.getInstallCmd();
    const args = [
        cmd === 'npm' ? 'i' : 'add',
        ...deps,
        isDev ? '--dev' : '',
        cmd === 'npm' ? '--save' : '',
        monorepo ? '-W' : '',
    ].filter(Boolean);
    await execa(cmd, args, {
        cwd: paths_1.resolveRoot(projectName),
    });
}
/**
 * 安装依赖
 *
 * @param {CreateOptions} options
 */
async function installDeps(spinner, options) {
    const { projectName } = options;
    const devDeps = getDevPendencies(options);
    spinner.start(messages_1.dependenciesMessage(constants_1.dependencies, devDeps));
    try {
        await execInstallDeps(projectName, constants_1.dependencies, false, true);
        await execInstallDeps(projectName, devDeps, true, true);
        spinner.succeed('安装依赖包');
        messages_1.successMessage(ts_lib_scripts_utils_1.getInstallCmd(), projectName);
    }
    catch (error) {
        spinner.fail(`安装依赖失败`);
        messages_1.failureMessage([
            ts_lib_scripts_utils_1.getInstallDepsCmd(constants_1.dependencies),
            ts_lib_scripts_utils_1.getInstallDepsCmd(devDeps, true),
        ]);
        process.exit(1);
    }
}
exports.default = installDeps;
//# sourceMappingURL=installDeps.js.map